==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/lib_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_library_item'] = 					"wiki page";
$lang['hdr_history'] = 							"recent history";
$lang['hdr_group_library'] = 					"group wiki page";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";
$lang['href_wiki_first_page'] = 				"start your library";
$lang['href_item_comments_only'] = 				"Show only the comment against this version of this page";
$lang['href_all_comments'] = 					"Show all comments associated with this page";
$lang['href_add_library'] = 					"add wiki page";
$lang['href_contents'] = 						"contents";


// ERROR
$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_my_options'] = 						"my options";
$lang['txt_group_options'] = 					"group options";
$lang['txt_library'] = 							"wiki";//breadcrumb
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_wiki_default'] = 					"LibraryFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_published_to'] = 					"Published to";
$lang['sub_check_spelling'] =					"Check Spelling";
$lang['txt_tag_intro'] = 						"This wiki page has been tagged with";
$lang['txt_item_tag'] = 						"This wiki page is tagged with with";

$lang['txt_option_items'] = 					"my wiki pages";
$lang['txt_option_marked'] = 					"marked wiki pages";
$lang['txt_option_tipped'] = 					"tipped wiki pages";
$lang['txt_option_list'] = 						"list entered for this wiki";
$lang['txt_option_edit'] = 						"edit this wiki page";
$lang['txt_option_add'] = 						"add a wiki page";
$lang['txt_option_contents'] = 					"contents";
$lang['txt_option_fpage'] = 					"first page";
$lang['txt_option_add'] = 						"add wiki page";
$lang['txt_group_link'] = 						"This wiki page is from the group";
$lang['txt_option_group_add'] = 				"add a group wiki page";
$lang['txt_option_group_edit'] = 				"edit this group wiki page";
$lang['txt_option_group_list'] = 				"list wiki pages for this group";

?>

==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/lib_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_library_item'] = 					"wiki page";
$lang['hdr_history'] = 							"recent history";
$lang['hdr_group_author'] = 					"authoring group";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";
$lang['href_item_comments_only'] = 				"Show only the comment against this version of this page";
$lang['href_all_comments'] = 					"Show all comments associated with this page";
$lang['href_add_library'] = 					"add wiki page";
$lang['href_add_group_library'] = 				"add wiki page to this group";
$lang['href_contents'] = 						"contents";
$lang['href_view_firstpage'] = 					"first page";
$lang['href_view_contents'] = 					"contents";
$lang['href_my_library'] = 						"my wiki pages";
$lang['href_marked'] = 							"marked wiki pages";


// ERROR
$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_library'] = 							"wiki";//breadcrumb
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_published_to'] = 					"Published to";
$lang['sub_check_spelling'] =					"Check Spelling";
$lang['txt_tag_intro'] = 						"This wiki page has been tagged with";
$lang['txt_item_tag'] = 						"This wiki page is tagged with with";
$lang['txt_view'] = 							"view";
$lang['txt_options'] = 							"options";
$lang['txt_group_link'] = 						"This blog is from the group";
$lang['txt_intro_contents_group'] = 			"Listed are the wiki pages that have been published by this group.";
$lang['txt_intro_contents'] = 					"Listed are the wiki pages that have been published by members of this community.";
$lang['txt_intro_history'] = 					"Listed is the history of this wiki page.";

?>
